@@ -67,14 +67,14 @@ int CupsHelper::port(){
 	return port_;
 }
 
-void CupsHelper::setHostInfo(const char *host, int port = 631){
+void CupsHelper::setHostInfo(const char *host, int port){
 	strcpy(host_,host);
 	cupsSetServer(host_);
 	port_ = port;
 	ippSetPort(port_);
 }
 
-void CupsHelper::setLoginInfo(const char *usr = 0, const char *pwd = 0){
+void CupsHelper::setLoginInfo(const char *usr, const char *pwd){
 	strcpy(login_,usr);
 	cupsSetUser(login_);
 	strcpy(password_,pwd);
