@@ -51,8 +51,8 @@ class CupsHelper {
 public: 
 	CupsHelper();
 	~CupsHelper();
-  static void setLoginInfo(const char *usr = 0, const char *pwd = 0);
-  static void setHostInfo(const char *host, int port = 631);
+  static void setLoginInfo(const char *usr, const char *pwd);
+  static void setHostInfo(const char *host, int port);
   static int port();
   static const char* host();
   static const char* password();
